# bfchain_pc_sdk

#### 介绍
bfchain_pc_sdk是在[BFChain（生物链林）](https://bfcc.dev/)区块链上开箱可用的Python开发者工具包

#### 软件架构



#### 安装教程
> 普通安装

开箱使用本工具包，仅需要使用pip安装即可。

```shell
pip install xxx
```
> 开发安装

贡献代码或者改善工具包的使用方式，下载/克隆源码后，需要安装相关依赖

```shell
pip install -r requirements.txt
```


#### 使用说明



#### 参与贡献




#### 特技


